You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@click.apache.org by sa...@apache.org on 2009/01/05 13:09:28 UTC

svn commit: r731537 [2/4] - in /incubator/click/trunk/click/framework: src/ src/org/apache/click/ src/org/apache/click/control/ src/org/apache/click/service/ src/org/apache/click/util/ test/org/ test/org/apache/ test/org/apache/click/ test/org/apache/c...

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Field.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/control/Field.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Field.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Field.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Field.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/HiddenField.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/HiddenField.java Mon Jan  5 04:09:22 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.io.IOException;
 import java.io.Serializable;
 import java.util.Date;
 
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides a Hidden Field control: &nbsp; &lt;input type='hidden'&gt;.
@@ -43,9 +43,9 @@
  * </ul></blockquote>
  * <p/>
  * Serializable non-primitive objects will be serialized, compressed and
- * Base64 encoded, using {@link net.sf.click.util.ClickUtils#encode(Object)}
+ * Base64 encoded, using {@link org.apache.click.util.ClickUtils#encode(Object)}
  * method, and decoded using the corresponding
- * {@link net.sf.click.util.ClickUtils#decode(String)} method.
+ * {@link org.apache.click.util.ClickUtils#decode(String)} method.
  *
  * <h3>HiddenField Example</h3>
  *
@@ -315,7 +315,7 @@
     /**
      * Render the HTML representation of the HiddenField.
      *
-     * @see net.sf.click.Control#render(net.sf.click.util.HtmlStringBuffer)
+     * @see org.apache.click.Control#render(org.apache.click.util.HtmlStringBuffer)
      *
      * @param buffer the specified buffer to render the control's output to
      */

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/HiddenField.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/HiddenField.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/HiddenField.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/ImageSubmit.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/ImageSubmit.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/ImageSubmit.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/ImageSubmit.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/ImageSubmit.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/ImageSubmit.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/ImageSubmit.java Mon Jan  5 04:09:22 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
-import net.sf.click.Context;
+import org.apache.click.Context;
 import org.apache.commons.lang.StringUtils;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides an ImageSubmit control: &nbsp; &lt;input type='image' src='edit.gif'&gt;.

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/ImageSubmit.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/ImageSubmit.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/ImageSubmit.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Label.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/control/Label.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Label.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Label.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Label.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Label.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Label.java Mon Jan  5 04:09:22 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides a Label display control. The Label control performs no server side
@@ -56,7 +56,7 @@
      * <p/>
      * If a value cannot be found in the parent or control messages then the
      * Field name will be converted into a label using the
-     * {@link net.sf.click.util.ClickUtils#toLabel(String)} method.
+     * {@link org.apache.click.util.ClickUtils#toLabel(String)} method.
      *
      * @param name the name of the Field
      */

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Label.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Label.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Label.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Option.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/Option.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Option.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Option.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Option.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Option.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Option.java Mon Jan  5 04:09:22 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.io.Serializable;
 import java.util.List;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides a select Option element: &nbsp; &lt;option&gt;&lt;/option&gt;.
@@ -211,7 +211,7 @@
     /**
      * Return a HTML rendered Option string.
      *
-     * @deprecated use {@link #render(net.sf.click.control.Select, net.sf.click.util.HtmlStringBuffer)}
+     * @deprecated use {@link #render(org.apache.click.control.Select, org.apache.click.util.HtmlStringBuffer)}
      * instead
      *
      * @param select the parent Select

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Option.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Option.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Option.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/OptionGroup.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/OptionGroup.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/OptionGroup.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/OptionGroup.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/OptionGroup.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/OptionGroup.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/OptionGroup.java Mon Jan  5 04:09:22 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides a select Option Group element: &nbsp; &lt;optgroup&gt;&lt;/optgroup&gt;.
@@ -141,7 +141,7 @@
     /**
      * Return a HTML rendered OptionGroup string.
      *
-     * @deprecated use {@link #render(net.sf.click.control.Select, net.sf.click.util.HtmlStringBuffer)}
+     * @deprecated use {@link #render(org.apache.click.control.Select, org.apache.click.util.HtmlStringBuffer)}
      * instead
      *
      * @param select the parent Select

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/OptionGroup.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/OptionGroup.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/OptionGroup.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/PageLink.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/PageLink.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/PageLink.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/PageLink.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/PageLink.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/PageLink.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/PageLink.java Mon Jan  5 04:09:22 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.util.Iterator;
 import java.util.Map;
 
-import net.sf.click.Context;
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.Context;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.HtmlStringBuffer;
 
 import org.apache.commons.lang.StringUtils;
 
@@ -43,8 +43,8 @@
  * <a class="external" target="_blank" title="W3C HTML 4.01 Specification"
  *    href="http://www.w3.org/TR/html401/struct/links.html#h-12.2">A Links</a>
  *
- * @see net.sf.click.control.AbstractLink
- * @see net.sf.click.control.ActionLink
+ * @see org.apache.click.control.AbstractLink
+ * @see org.apache.click.control.ActionLink
  *
  * @author Malcolm Edgar
  */
@@ -174,7 +174,7 @@
     /**
      * This method does nothing.
      *
-     * @see net.sf.click.Control#setListener(Object, String)
+     * @see org.apache.click.Control#setListener(Object, String)
      *
      * @param listener the listener object with the named method to invoke
      * @param method the name of the method to invoke
@@ -206,7 +206,7 @@
     /**
      * This method will return true.
      *
-     * @see net.sf.click.Control#onProcess()
+     * @see org.apache.click.Control#onProcess()
      *
      * @return true
      */

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/PageLink.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Panel.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/control/Panel.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Panel.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Panel.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Panel.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/PasswordField.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/PasswordField.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 /**
  * Provides a Password Field control: &nbsp; &lt;input type='password'&gt;.
@@ -28,7 +28,7 @@
  * </tr>
  * </table>
  *
- * For an PasswordField code example see the {@link net.sf.click.control.Form}
+ * For an PasswordField code example see the {@link org.apache.click.control.Form}
  * Javadoc example.
  * <p/>
  * See also W3C HTML reference

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/PasswordField.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/PasswordField.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/PasswordField.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Radio.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/Radio.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Radio.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Radio.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Radio.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/RadioGroup.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/RadioGroup.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.text.MessageFormat;
 import java.util.ArrayList;
@@ -26,8 +26,8 @@
 import java.util.List;
 import java.util.Map;
 
-import net.sf.click.util.HtmlStringBuffer;
-import net.sf.click.util.PropertyUtils;
+import org.apache.click.util.HtmlStringBuffer;
+import org.apache.click.util.PropertyUtils;
 
 /**
  * Provides a RadioGroup control.
@@ -403,7 +403,7 @@
     // --------------------------------------------------------- Public Methods
 
     /**
-     * @see net.sf.click.Control#onInit()
+     * @see org.apache.click.Control#onInit()
      */
     public void onInit() {
         super.onInit();
@@ -417,7 +417,7 @@
      * Process the request Context setting the checked value and invoking
      * the controls listener if defined.
      *
-     * @see net.sf.click.Control#onProcess()
+     * @see org.apache.click.Control#onProcess()
      *
      * @return true to continue Page event processing or false otherwise
      */
@@ -442,7 +442,7 @@
     }
 
     /**
-     * @see net.sf.click.Control#onDestroy()
+     * @see org.apache.click.Control#onDestroy()
      */
     public void onDestroy() {
         for (int i = 0, size = getRadioList().size(); i < size; i++) {
@@ -520,7 +520,7 @@
      * <p/>
      * A field error message is displayed if a validation error occurs.
      * These messages are defined in the resource bundle: <blockquote>
-     * <pre>net.sf.click.control.MessageProperties</pre></blockquote>
+     * <pre>org.apache.click.control.MessageProperties</pre></blockquote>
      * <p/>
      * Error message bundle key names include: <blockquote><ul>
      * <li>field-required-error</li>

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/RadioGroup.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/RadioGroup.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/RadioGroup.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Renderable.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/control/Renderable.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Renderable.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Renderable.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Renderable.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Renderable.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Renderable.java Mon Jan  5 04:09:22 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.io.Serializable;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides an interface for rendering output to an efficient string buffer.

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Renderable.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Reset.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/Reset.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Reset.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Reset.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Reset.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Reset.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Reset.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 /**
  * Provides a Reset control: &nbsp; &lt;input type='reset'&gt;.

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Reset.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Reset.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Reset.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Select.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/Select.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Select.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Select.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Select.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Submit.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Submit.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import org.apache.commons.lang.StringUtils;
 
@@ -32,7 +32,7 @@
  * The Submit control supports server side processing and can be used to invoke
  * Control listeners.
  * <p/>
- * For an Submit code example see the {@link net.sf.click.control.Form}
+ * For an Submit code example see the {@link org.apache.click.control.Form}
  * Javadoc example.
  * <p/>
  * See also the W3C HTML reference

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Submit.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Submit.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Submit.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Table.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/Table.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Table.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Table.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Table.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/TablePaginator.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/TablePaginator.java Mon Jan  5 04:09:22 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides the default Table Paginator.
@@ -205,7 +205,7 @@
      * Returns the HTML representation of this paginator.
      * <p/>
      * This method delegates the rendering to the method
-     * {@link #render(net.sf.click.util.HtmlStringBuffer)}.
+     * {@link #render(org.apache.click.util.HtmlStringBuffer)}.
      *
      * @see Object#toString()
      *

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/TablePaginator.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/TextArea.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/TextArea.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/TextArea.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/TextArea.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/TextArea.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/TextArea.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/TextArea.java Mon Jan  5 04:09:22 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.text.MessageFormat;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides a TextArea control: &nbsp; &lt;textarea&gt;&lt;/textarea&gt;.
@@ -367,7 +367,7 @@
      * <p/>
      * A field error message is displayed if a validation error occurs.
      * These messages are defined in the resource bundle: <blockquote>
-     * <pre>net.sf.click.control.MessageProperties</pre></blockquote>
+     * <pre>org.apache.click.control.MessageProperties</pre></blockquote>
      * <p/>
      * Error message bundle key names include: <blockquote><ul>
      * <li>field-maxlength-error</li>

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/TextArea.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/TextArea.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/TextArea.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/TextField.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/TextField.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/TextField.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/TextField.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/TextField.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/TextField.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/TextField.java Mon Jan  5 04:09:22 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.text.MessageFormat;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides a Text Field control: &nbsp; &lt;input type='text'&gt;.
@@ -50,7 +50,7 @@
  * <pre class="codeHtml">
  * &lt;input type='text' name='username' value='' size='12' maxlength='12'&gt; </pre>
  *
- * For another example using TextField see the {@link net.sf.click.control.Form}
+ * For another example using TextField see the {@link org.apache.click.control.Form}
  * Javadoc example.
  * <p/>
  * See also the W3C HTML reference:
@@ -348,7 +348,7 @@
      * <p/>
      * A field error message is displayed if a validation error occurs.
      * These messages are defined in the resource bundle: <blockquote>
-     * <pre>net.sf.click.control.MessageProperties</pre></blockquote>
+     * <pre>org.apache.click.control.MessageProperties</pre></blockquote>
      * <p/>
      * Error message bundle key names include: <blockquote><ul>
      * <li>field-maxlength-error</li>

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/TextField.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/TextField.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/TextField.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/VM_global_library.vm
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-ascending-dark.gif
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-ascending-dark.gif
------------------------------------------------------------------------------
    svn:mime-type = application/octet-stream

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-ascending-light.gif
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-ascending-light.gif
------------------------------------------------------------------------------
    svn:mime-type = application/octet-stream

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-descending-dark.gif
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-descending-dark.gif
------------------------------------------------------------------------------
    svn:mime-type = application/octet-stream

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-descending-light.gif
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-descending-light.gif
------------------------------------------------------------------------------
    svn:mime-type = application/octet-stream

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-sortable-dark.gif
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-sortable-dark.gif
------------------------------------------------------------------------------
    svn:mime-type = application/octet-stream

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-sortable-light.gif
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-sortable-light.gif
------------------------------------------------------------------------------
    svn:mime-type = application/octet-stream

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-sorted-dark.gif
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-sorted-dark.gif
------------------------------------------------------------------------------
    svn:mime-type = application/octet-stream

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-sorted-light.gif
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/column-sorted-light.gif
------------------------------------------------------------------------------
    svn:mime-type = application/octet-stream

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/control.css
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/control.js
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/image-submit.gif
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/image-submit.gif
------------------------------------------------------------------------------
    svn:mime-type = application/octet-stream

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/package.html (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/control/package.html)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/package.html?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/package.html&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/package.html&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/package.html (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/package.html Mon Jan  5 04:09:22 2009
@@ -19,7 +19,7 @@
 
 <body>
 Provides renderable HTML controls. Controls implement the
-{@link net.sf.click.Control} interface to perform server side request
+{@link org.apache.click.Control} interface to perform server side request
 processing. At the top level a Pages controls are processed by the
 ClickServlet. Some controls can contain child controls which they will inturn
 process. These container controls include Form, FieldSet, Panel and Table.
@@ -30,11 +30,11 @@
 
 <h3>Action Listeners</h3>
 
-Controls extending {@link net.sf.click.control.AbstractControl} can use an action
+Controls extending {@link org.apache.click.control.AbstractControl} can use an action
 listener event callback mechanism similar the <tt>java.awt.ActionListener</tt> callback.
 <p/>
 Click supports two styles of action listeners, the first is using the
-{@link net.sf.click.ActionListener} interface which provides compile time safety.
+{@link org.apache.click.ActionListener} interface which provides compile time safety.
 The second is to register the action listener via the <tt>setListener(Object, String)</tt>
 method where you specify the call back method via its name. This second style uses
 less lines of code, but has no compile time safety.

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/package.html
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/package.html
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/package.html
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/table.css
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/table.css
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/not-found.htm
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/not-found.htm
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/not-found.htm
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/package.html (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/package.html)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/package.html?p2=incubator/click/trunk/click/framework/src/org/apache/click/package.html&p1=incubator/click/trunk/click/framework/src/net/sf/click/package.html&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/package.html (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/package.html Mon Jan  5 04:09:22 2009
@@ -21,12 +21,12 @@
 Provides the main Click runtime components.
 <p/>
 This package defines the core application runtime classes and 
-exception. The main class developers will use is the {@link net.sf.click.Page} 
+exception. The main class developers will use is the {@link org.apache.click.Page} 
 class which provides application pages, the 
-{@link net.sf.click.Context} class which provides page's their request context,
-and {@link net.sf.click.Control} interface which Page controls extend.
+{@link org.apache.click.Context} class which provides page's their request context,
+and {@link org.apache.click.Control} interface which Page controls extend.
 <p/>
-Other classes include the {@link net.sf.click.ClickServlet} which provides the Click 
+Other classes include the {@link org.apache.click.ClickServlet} which provides the Click 
 runtime environment, and <tt>ClickApp</tt> which encapsulates the Click application 
 configuration.  This class has package private visibility and are not intended for 
 general use. Of course as an open source project this class can be modified to suite

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/package.html
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/package.html
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/package.html
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/service/CommonsFileUploadService.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/service/CommonsFileUploadService.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/service/CommonsFileUploadService.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/service/CommonsFileUploadService.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/service/CommonsFileUploadService.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/service/CommonsFileUploadService.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/service/CommonsFileUploadService.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.service;
+package org.apache.click.service;
 
 import java.util.List;
 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/service/CommonsFileUploadService.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/service/ConfigService.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/service/ConfigService.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/service/ConfigService.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/service/ConfigService.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/service/ConfigService.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/service/ConsoleLogService.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/service/ConsoleLogService.java Mon Jan  5 04:09:22 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.service;
+package org.apache.click.service;
 
 import javax.servlet.ServletContext;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides a Log Service class which will log messages to the console or

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/service/ConsoleLogService.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/service/FileUploadService.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/service/FileUploadService.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/service/FileUploadService.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/service/FileUploadService.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/service/FileUploadService.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/service/FileUploadService.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/service/FileUploadService.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.service;
+package org.apache.click.service;
 
 import java.util.List;
 
@@ -34,7 +34,7 @@
 public interface FileUploadService {
 
     /** The attribute key used for storing an upload exception. */
-    public static final String UPLOAD_EXCEPTION = "net.sf.click.service.upload_exception";
+    public static final String UPLOAD_EXCEPTION = "org.apache.click.service.upload_exception";
 
     /**
      * Initialize the FileUploadService with the given application servlet context.
@@ -42,7 +42,7 @@
      * This method is invoked after the FileUploadService has been constructed.
      * <p/>
      * Note you can access {@link ConfigService} by invoking
-     * {@link net.sf.click.util.ClickUtils#getConfigService(javax.servlet.ServletContext)}
+     * {@link org.apache.click.util.ClickUtils#getConfigService(javax.servlet.ServletContext)}
      *
      * @param servletContext the application servlet context
      * @throws Exception if an error occurs initializing the FileUploadService

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/service/FileUploadService.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/service/LogService.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/service/LogService.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/service/LogService.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/service/LogService.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/service/LogService.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/service/LogService.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/service/LogService.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.service;
+package org.apache.click.service;
 
 import javax.servlet.ServletContext;
 
@@ -33,7 +33,7 @@
  * &lt;?xml version="1.0" encoding="UTF-8" standalone="yes"?&gt;
  * &lt;click-app charset="UTF-8"&gt;
  *
- *     &lt;pages package="net.sf.click.examples.page"/&gt;
+ *     &lt;pages package="org.apache.click.examples.page"/&gt;
  *
  *     &lt;<span class="red">log-service</span> classname="<span class="blue">com.mycorp.CustomLogService</span>"/&gt;
  *
@@ -64,7 +64,7 @@
      * This method is invoked after the LogService has been constructed.
      * <p/>
      * Note you can access {@link ConfigService} by invoking
-     * {@link net.sf.click.util.ClickUtils#getConfigService(javax.servlet.ServletContext)}
+     * {@link org.apache.click.util.ClickUtils#getConfigService(javax.servlet.ServletContext)}
      *
      * @param servletContext the application servlet context
      * @throws Exception if an error occurs initializing the LogService

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/service/LogService.java
------------------------------------------------------------------------------
    svn:mergeinfo =
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Field.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Field.java Mon Jan  5 04:09:22 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
-import net.sf.click.Control;
-import net.sf.click.Page;
+import org.apache.click.Control;
+import org.apache.click.Page;
 import org.apache.commons.lang.StringUtils;
 
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.ContainerUtils;
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.ContainerUtils;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides an abstract form Field control. Field controls are contained by
@@ -102,7 +102,7 @@
  * method.
  * <p/>
  * To assist with rendering valid HTML Field subclasses can use the
- * {@link net.sf.click.util.HtmlStringBuffer} class.
+ * {@link org.apache.click.util.HtmlStringBuffer} class.
  *
  * <h3>Message Resources</h3>
  *
@@ -246,7 +246,7 @@
     /**
      * Set the parent of the Field.
      *
-     * @see net.sf.click.Control#setParent(Object)
+     * @see org.apache.click.Control#setParent(Object)
      *
      * @param parent the parent of the Control
      * @throws IllegalStateException if {@link #name} is not defined
@@ -465,7 +465,7 @@
      * <p/>
      * Use the field the "id" attribute value if defined, or the name otherwise.
      *
-     * @see net.sf.click.Control#getId()
+     * @see org.apache.click.Control#getId()
      *
      * @return HTML element identifier attribute "id" value
      */
@@ -573,7 +573,7 @@
      * value is valid. If the field has validation errors the listener will not
      * be called.
      *
-     * @see net.sf.click.Control#getName()
+     * @see org.apache.click.Control#getName()
      *
      * @param listener the listener object with the named method to invoke
      * @param method the name of the method to invoke
@@ -776,7 +776,7 @@
     /**
      * Return true if the Field is valid after being processed, or false
      * otherwise. If the Field has no error message after
      * {@link net.sf.click.Control#onProcess()} has been invoked it is considered to be
      * valid.
      *
      * @return true if the Field is valid after being processed
@@ -864,7 +864,7 @@
      * This method does nothing. Subclasses may override this method to perform
      * additional initialization.
      *
-     * @see net.sf.click.Control#onInit()
+     * @see org.apache.click.Control#onInit()
      */
     public void onInit() {
         super.onInit();

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Field.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Field.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Field.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -776,7 +776,7 @@
      * Return true if the Field is valid after being processed, or false
      * otherwise. If the Field has no error message after
-     * {@link net.sf.click.Control#onProcess()} has been invoked it is considered to be
+     * {@link org.apache.click.Control#onProcess()} has been invoked it is considered to be
      * valid.
      *

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/FieldSet.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/FieldSet.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/FieldSet.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/FieldSet.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/FieldSet.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/FieldSet.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/FieldSet.java Mon Jan  5 04:09:22 2009
@@ -16,19 +16,19 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import net.sf.click.ActionListener;
-import net.sf.click.Context;
-import net.sf.click.Control;
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.ContainerUtils;
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.ActionListener;
+import org.apache.click.Context;
+import org.apache.click.Control;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.ContainerUtils;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides a FieldSet container control: &nbsp; &lt;fieldset&gt;.
@@ -177,7 +177,7 @@
      * it will automatically be removed from that parent and inserted into the
      * fieldSet.
      *
-     * @see Container#add(net.sf.click.Control)
+     * @see Container#add(org.apache.click.Control)
      *
      * @param control the control to add to the FieldSet and return
      * @param index the index at which the control is to be inserted
@@ -200,7 +200,7 @@
      * in the order they were added. If you are only interested in Fields,
      * note fields are available on {@link #getFieldList() fieldList}.
      *
-     * @see net.sf.click.control.Container#add(net.sf.click.Control).
+     * @see org.apache.click.control.Container#add(org.apache.click.Control).
      *
      * @param control the control to add to the container and return
      * @return the control that was added to the container
@@ -221,7 +221,7 @@
      * <p/>
      * Fields are available on {@link #getFieldList() fieldList}.
      *
-     * @see #add(net.sf.click.Control)
+     * @see #add(org.apache.click.Control)
      *
      * @param field the field to add to the fieldSet
      * @return the field added to this fieldSet
@@ -291,7 +291,7 @@
     }
 
     /**
-     * @see Container#remove(net.sf.click.Control)
+     * @see Container#remove(org.apache.click.Control)
      *
      * @param control the control to remove from the container
      * @return true if the control was removed from the container
@@ -331,7 +331,7 @@
     }
 
     /**
-     * @see net.sf.click.control.Container#getControls()
+     * @see org.apache.click.control.Container#getControls()
      *
      * @return the sequential list of controls held by the container
      */
@@ -340,7 +340,7 @@
     }
 
     /**
-     * @see net.sf.click.control.Container#getControl(java.lang.String)
+     * @see org.apache.click.control.Container#getControl(java.lang.String)
      *
      * @param controlName the name of the control to get from the container
      * @return the named control from the container if found or null otherwise
@@ -350,7 +350,7 @@
     }
 
     /**
-     * @see net.sf.click.control.Container#contains(net.sf.click.Control)
+     * @see org.apache.click.control.Container#contains(org.apache.click.Control)
      *
      * @param control the control whose presence in this container is to be tested
      * @return true if the container contains the specified control
@@ -560,7 +560,7 @@
     /**
      * Return the HTML head import statements for contained fields.
      *
-     * @see net.sf.click.Control#getHtmlImports()
+     * @see org.apache.click.Control#getHtmlImports()
      *
      * @return the HTML head import statements for the contained field stylesheet
      * and JavaScript files
@@ -709,21 +709,21 @@
     }
 
     /**
-     * @see net.sf.click.Control#onDestroy()
+     * @see org.apache.click.Control#onDestroy()
      */
     public void onDestroy() {
         container.onDestroy();
     }
 
     /**
-     * @see net.sf.click.Control#onInit()
+     * @see org.apache.click.Control#onInit()
      */
     public void onInit() {
         container.onInit();
     }
 
     /**
-     * @see net.sf.click.Control#onRender()
+     * @see org.apache.click.Control#onRender()
      */
     public void onRender() {
         container.onRender();
@@ -733,7 +733,7 @@
      * This method is not supported and will throw a
      * <tt>UnsupportedOperationException</tt>.
      *
-     * @see net.sf.click.Control#setListener(Object, String)
+     * @see org.apache.click.Control#setListener(Object, String)
      *
      * @param listener the listener object with the named method to invoke
      * @param method the name of the method to invoke
@@ -746,7 +746,7 @@
      * This method is not supported and will throw a
      * <tt>UnsupportedOperationException</tt>.
      *
-     * @see net.sf.click.control.AbstractControl#setActionListener(ActionListener)
+     * @see org.apache.click.control.AbstractControl#setActionListener(ActionListener)
      *
      * @param actionListener the control's action listener
      */
@@ -814,7 +814,7 @@
      * Returns the HTML representation of the FieldSet.
      * <p/>
      * The rendering of the FieldSet is delegated to
      * {@link #render(net.sf.click.util.HtmlStringBuffer)}. The size of buffer
      * is determined by {@link #getControlSizeEst()}.
      *
      * @see Object#toString()
@@ -833,7 +833,7 @@
      * Return the map of controls where each map's key / value pair will consist
      * of the control name and instance.
      *
-     * @see net.sf.click.control.AbstractContainer#getControlMap()
+     * @see org.apache.click.control.AbstractContainer#getControlMap()
      *
      * @return the map of controls
      */
@@ -842,7 +842,7 @@
     }
 
     /**
-     * @see net.sf.click.control.AbstractControl#getControlSizeEst()
+     * @see org.apache.click.control.AbstractControl#getControlSizeEst()
      *
      * @return the estimated rendered control size in characters
      */
@@ -1095,7 +1095,7 @@
         /**
          * Add a Field to the FieldSet and return the added instance.
          *
-         * @see Container#add(net.sf.click.Control)
+         * @see Container#add(org.apache.click.Control)
          *
          * @param control the control to add to the FieldSet and return
          * @param index the index at which the control is to be inserted
@@ -1136,7 +1136,7 @@
         }
 
         /**
-         * @see net.sf.click.control.Container#remove(net.sf.click.Control).
+         * @see org.apache.click.control.Container#remove(org.apache.click.Control).
          *
          * @param control the control to remove from the container
          * @return true if the control was removed from the container

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/FieldSet.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/FieldSet.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -814,7 +814,7 @@
      * <p/>
      * The rendering of the FieldSet is delegated to
-     * {@link #render(net.sf.click.util.HtmlStringBuffer)}. The size of buffer
+     * {@link #render(org.apache.click.util.HtmlStringBuffer)}. The size of buffer
      * is determined by {@link #getControlSizeEst()}.
      *

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/FileField.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/control/FileField.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/FileField.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/FileField.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/FileField.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/FileField.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/FileField.java Mon Jan  5 04:09:22 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.text.MessageFormat;
 
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.lang.StringUtils;
@@ -39,9 +39,9 @@
  * <a href="http://jakarta.apache.org/commons/fileupload/">FileUpload</a>
  * library to provide file processing functionality.
  * <p/>
  * You can control the {@link net.sf.click.service.CommonsFileUploadService#sizeMax maximum request size}
  * and {@link net.sf.click.service.CommonsFileUploadService#fileSizeMax maximum file size}
  * by configuring {@link net.sf.click.service.CommonsFileUploadService}.
  * <p/>
  * Note Browsers enforce the JavaScript <tt>value</tt> property as readonly
  * to prevent script based stealing of users files.

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/FileField.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/FileField.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/FileField.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -39,9 +39,9 @@
  * library to provide file processing functionality.
  * <p/>
- * You can control the {@link net.sf.click.service.CommonsFileUploadService#sizeMax maximum request size}
- * and {@link net.sf.click.service.CommonsFileUploadService#fileSizeMax maximum file size}
- * by configuring {@link net.sf.click.service.CommonsFileUploadService}.
+ * You can control the {@link org.apache.click.service.CommonsFileUploadService#sizeMax maximum request size}
+ * and {@link org.apache.click.service.CommonsFileUploadService#fileSizeMax maximum file size}
+ * by configuring {@link org.apache.click.service.CommonsFileUploadService}.
  * <p/>
  * Note Browsers enforce the JavaScript <tt>value</tt> property as readonly

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Form.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/Form.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Form.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Form.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Form.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Form.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Form.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -27,14 +27,14 @@
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import net.sf.click.Context;
-import net.sf.click.Control;
-import net.sf.click.Page;
-import net.sf.click.service.FileUploadService;
-import net.sf.click.service.LogService;
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.ContainerUtils;
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.Context;
+import org.apache.click.Control;
+import org.apache.click.Page;
+import org.apache.click.service.FileUploadService;
+import org.apache.click.service.LogService;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.ContainerUtils;
+import org.apache.click.util.HtmlStringBuffer;
 
 import org.apache.commons.fileupload.FileUploadBase.FileSizeLimitExceededException;
 import org.apache.commons.fileupload.FileUploadBase.SizeLimitExceededException;
@@ -176,8 +176,8 @@
  * Multipart requests are used when uploading files from the client.
  * <p/>
  * The {@link #validate()} method checks that files being uploaded do not exceed the
  * {@link net.sf.click.service.CommonsFileUploadService#sizeMax maximum request size}
  * or the {@link net.sf.click.service.CommonsFileUploadService#fileSizeMax maximum file size}.
  * <p/>
  * <b>Please note</b> that if the <tt>maximum request size</tt> or <tt>maximum file size</tt>
  * is exceeded, the request is deemed {@link #hasPostError invalid} and no further
@@ -443,7 +443,7 @@
  * article for more information on this topic.
  * <p/>
  * To prevent multiple form posts from use of the browser back button use one
  * of the Form {@link #onSubmitCheck(net.sf.click.Page, String)} methods. For example:
  *
  * <pre class="codeJava">
  * <span class="kw">public class</span> Purchase <span class="kw">extends</span> Page {
@@ -657,7 +657,7 @@
      * note that Buttons are available on the {@link #getButtonList() buttonList}
      * while other fields are available on {@link #getFieldList() fieldList}.
      *
-     * @see Container#add(net.sf.click.Control)
+     * @see Container#add(org.apache.click.Control)
      *
      * @param control the control to add to the container and return
      * @return the control that was added to the container
@@ -693,7 +693,7 @@
      * hidden fields might influence the position of the Control you insert.
      * <em>This restriction might be removed in a future version of Click.</em>
      *
-     * @see net.sf.click.control.Container#insert(net.sf.click.Control, int)
+     * @see org.apache.click.control.Container#insert(org.apache.click.Control, int)
      *
      * @param control the control to add to the container
      * @param index the index at which the control is to be inserted
@@ -748,7 +748,7 @@
      * Buttons are available on the {@link #getButtonList() buttonList} while
      * other fields are available on {@link #getFieldList() fieldList}.
      *
-     * @see #add(net.sf.click.Control)
+     * @see #add(org.apache.click.Control)
      *
      * @param field the field to add to the form
      * @return the field added to this form
@@ -770,7 +770,7 @@
      * <p/>
      * Note Button and HiddenField types are not valid arguments for this method.
      *
-     * @see #add(net.sf.click.Control)
+     * @see #add(org.apache.click.Control)
      *
      * @param field the field to add to the form
      * @param width the width of the field in table columns
@@ -794,7 +794,7 @@
      * <p/>
      * Note Button and HiddenField types are not valid arguments for this method.
      *
-     * @see #add(net.sf.click.Control)
+     * @see #add(org.apache.click.Control)
      *
      * @param control the control to add to the form
      * @param width the width of the control in table columns
@@ -821,7 +821,7 @@
     }
 
     /**
-     * @see Container#remove(net.sf.click.Control)
+     * @see Container#remove(org.apache.click.Control)
      *
      * @param control the control to remove from the container
      * @return true if the control was removed from the container
@@ -1066,7 +1066,7 @@
      * (<tt>click/control.css</tt>) and JavaScript
      * (<tt>click/control.js</tt>) files.
      *
-     * @see net.sf.click.Control#getHtmlImports()
+     * @see org.apache.click.Control#getHtmlImports()
      *
      * @return the HTML head import statements for the control stylesheet and
      * JavaScript files
@@ -1136,7 +1136,7 @@
     /**
      * Set the name of the form.
      *
-     * @see net.sf.click.Control#setName(String)
+     * @see org.apache.click.Control#setName(String)
      *
      * @param name of the control
      * @throws IllegalArgumentException if the name is null
@@ -1524,7 +1524,7 @@
      * value is valid. If the field has validation errors the listener will not
      * be called.
      *
-     * @see net.sf.click.Control#setListener(Object, String)
+     * @see org.apache.click.Control#setListener(Object, String)
      *
      * @param listener the listener object with the named method to invoke
      * @param method the name of the method to invoke
@@ -1604,7 +1604,7 @@
      *  }
      * </pre>
      * For more information on how Fields and Objects are copied see
-     * {@link net.sf.click.util.ContainerUtils#copyObjectToContainer(java.lang.Object, net.sf.click.control.Container)}.
+     * {@link org.apache.click.util.ContainerUtils#copyObjectToContainer(java.lang.Object, org.apache.click.control.Container)}.
      *
      * @param object the object to obtain attribute values from
      * @throws IllegalArgumentException if the object parameter is null
@@ -1676,7 +1676,7 @@
      * from.
      *
      * For more information on how Fields and Objects are copied see
-     * {@link net.sf.click.util.ContainerUtils#copyContainerToObject(net.sf.click.control.Container, java.lang.Object)}.
+     * {@link org.apache.click.util.ContainerUtils#copyContainerToObject(org.apache.click.control.Container, java.lang.Object)}.
      *
      * @param object the object to populate with field values
      * @throws IllegalArgumentException if the object parameter is null
@@ -1717,8 +1717,8 @@
      * <li>Invoke the Forms listener if defined</li>
      * </ol>
      *
-     * @see net.sf.click.Context#getRequestParameter(String)
-     * @see net.sf.click.Context#getFileItemMap()
+     * @see org.apache.click.Context#getRequestParameter(String)
+     * @see org.apache.click.Context#getFileItemMap()
      *
      * @return true to continue Page event processing or false otherwise
      */
@@ -1762,7 +1762,7 @@
      * Destroy the controls contained in the Form and clear any form
      * error message.
      *
-     * @see net.sf.click.Control#onDestroy()
+     * @see org.apache.click.Control#onDestroy()
      */
     public void onDestroy() {
         super.onDestroy();

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Form.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Form.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Form.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -176,8 +176,8 @@
  * <p/>
  * The {@link #validate()} method checks that files being uploaded do not exceed the
- * {@link net.sf.click.service.CommonsFileUploadService#sizeMax maximum request size}
- * or the {@link net.sf.click.service.CommonsFileUploadService#fileSizeMax maximum file size}.
+ * {@link org.apache.click.service.CommonsFileUploadService#sizeMax maximum request size}
+ * or the {@link org.apache.click.service.CommonsFileUploadService#fileSizeMax maximum file size}.
  * <p/>
  * <b>Please note</b> that if the <tt>maximum request size</tt> or <tt>maximum file size</tt>
@@ -443,7 +443,7 @@
  * <p/>
  * To prevent multiple form posts from use of the browser back button use one
- * of the Form {@link #onSubmitCheck(net.sf.click.Page, String)} methods. For example:
+ * of the Form {@link #onSubmitCheck(org.apache.click.Page, String)} methods. For example:
  *
  * <pre class="codeJava">

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/HiddenField.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/HiddenField.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/HiddenField.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/HiddenField.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/HiddenField.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Panel.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Panel.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -26,14 +26,14 @@
 
 import javax.servlet.http.HttpServletRequest;
 
-import net.sf.click.ActionListener;
-import net.sf.click.Context;
-import net.sf.click.Control;
-import net.sf.click.Page;
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.Format;
-import net.sf.click.util.HtmlStringBuffer;
-import net.sf.click.util.SessionMap;
+import org.apache.click.ActionListener;
+import org.apache.click.Context;
+import org.apache.click.Control;
+import org.apache.click.Page;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.Format;
+import org.apache.click.util.HtmlStringBuffer;
+import org.apache.click.util.SessionMap;
 
 /**
  * Provides a Panel control for creating customized layout sections within a page.
@@ -193,7 +193,7 @@
     // ------------------------------------------------------------- Properties
 
     /**
-     * @see #add(net.sf.click.Control)
+     * @see #add(org.apache.click.Control)
      *
      * @param control the control to add to the container
      * @return the control that was added to the container
@@ -209,7 +209,7 @@
      * Add the control to the panel and return the specified control.
      * <p/>
      * In addition to the requirements specified by
-     * {@link Container#add(net.sf.click.Control)}, note
+     * {@link Container#add(org.apache.click.Control)}, note
      * the following:
      * <ul>
      *  <li>
@@ -226,7 +226,7 @@
      *   {@link #getPanels()}.
      *  </li>
      * </ul>
-     * @see net.sf.click.control.Container#add(net.sf.click.Control)
+     * @see org.apache.click.control.Container#add(org.apache.click.Control)
      *
      * @param control the control to add to the container
      * @return the control that was added to the container
@@ -250,7 +250,7 @@
     }
 
     /**
-     * @see #remove(net.sf.click.Control)
+     * @see #remove(org.apache.click.Control)
      *
      * @param control the control to remove from the container
      * @return true if the control was removed from the container
@@ -267,10 +267,10 @@
      * found.
      * <p/>
      * In addition to the requirements specified by
      * {@link Container#remove(net.sf.click.Control)}, the controls name
      * must also be set.
      *
-     * @see net.sf.click.control.Container#remove(net.sf.click.Control)
+     * @see org.apache.click.control.Container#remove(org.apache.click.Control)
      *
      * @param control the control to remove from the container
      * @return true if the control was removed from the container
@@ -315,7 +315,7 @@
      * will return the panel name. If no name is defined this method will return
      * <tt>null</tt>.
      *
-     * @see net.sf.click.Control#getId()
+     * @see org.apache.click.Control#getId()
      *
      * @return the panel HTML id attribute value
      */
@@ -416,7 +416,7 @@
      * This method does nothing, since Panel does not support action listener
      * callback.
      *
-     * @see AbstractControl#setActionListener(net.sf.click.ActionListener)
+     * @see AbstractControl#setActionListener(org.apache.click.ActionListener)
      *
      * @param listener the control's action listener
      */

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Panel.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Panel.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Panel.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -267,10 +267,10 @@
      * <p/>
      * In addition to the requirements specified by
-     * {@link Container#remove(net.sf.click.Control)}, the controls name
+     * {@link Container#remove(org.apache.click.Control)}, the controls name
      * must also be set.
      *

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/PasswordField.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/PasswordField.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/PasswordField.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/PasswordField.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/PasswordField.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Radio.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Radio.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Provides a Radio control: &nbsp; &lt;input type='radio'&gt;.
@@ -31,7 +31,7 @@
  * </table>
  *
  * The Radio control is generally used within a RadioGroup, for an code example
  * pleasse see the {@link net.sf.click.control.RadioGroup} Javadoc example.
  * When used with a RadioGroup the Radio control will derrive its name from the
  * parent RadioGroup, if the Radio's name is not defined.
  *
@@ -167,7 +167,7 @@
     /**
      * Set the parent of the Field.
      *
-     * @see net.sf.click.Control#setParent(Object)
+     * @see org.apache.click.Control#setParent(Object)
      *
      * @param parent the parent of the Control
      * @throws IllegalArgumentException if the given parent instance is

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Radio.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Radio.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Radio.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -31,7 +31,7 @@
  *
  * The Radio control is generally used within a RadioGroup, for an code example
- * pleasse see the {@link net.sf.click.control.RadioGroup} Javadoc example.
+ * pleasse see the {@link org.apache.click.control.RadioGroup} Javadoc example.
  * When used with a RadioGroup the Radio control will derrive its name from the
  * parent RadioGroup, if the Radio's name is not defined.

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/RadioGroup.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/RadioGroup.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/RadioGroup.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/RadioGroup.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/RadioGroup.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Select.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Select.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.text.MessageFormat;
 import java.util.ArrayList;
@@ -27,8 +27,8 @@
 import java.util.List;
 import java.util.Map;
 
-import net.sf.click.util.HtmlStringBuffer;
-import net.sf.click.util.PropertyUtils;
+import org.apache.click.util.HtmlStringBuffer;
+import org.apache.click.util.PropertyUtils;
 
 /**
  * Provides a Select control: &nbsp; &lt;select&gt;&lt;/select&gt;.
@@ -166,7 +166,7 @@
  * <h3>Specify a default value</h3>
  *
  * It is often necessary to set a default selected value. This is best done in
  * the {@link net.sf.click.Page#onRender()} method:
  * <pre class="prettyprint">
  * public MyPage extends Page {
  *     private Select mySelect;

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Select.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Select.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Select.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -166,7 +166,7 @@
  *
  * It is often necessary to set a default selected value. This is best done in
- * the {@link net.sf.click.Page#onRender()} method:
+ * the {@link org.apache.click.Page#onRender()} method:
  * <pre class="prettyprint">
  * public MyPage extends Page {

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/Submit.java (from r731262, incubator/click/trunk/click/framework/src/net/sf/click/control/Submit.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/Submit.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/Submit.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/Submit.java&r1=731262&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/control/Table.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/control/Table.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -29,10 +29,10 @@
 
 import javax.servlet.ServletContext;
 
-import net.sf.click.Context;
-import net.sf.click.Control;
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.Context;
+import org.apache.click.Control;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.HtmlStringBuffer;
 
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.math.NumberUtils;
@@ -193,7 +193,7 @@
  * } </pre>
  *
  * Table supports rendering different paginators through the method
  * {@link #setPaginator(net.sf.click.control.Renderable)}. The default Table
  * Paginator is {@link TablePaginator}.
  *
  * <a name="row-attributes"></a>
@@ -449,7 +449,7 @@
     /**
      * Set the parent of the Table.
      *
-     * @see net.sf.click.Control#setParent(Object)
+     * @see org.apache.click.Control#setParent(Object)
      *
      * @param parent the parent of the Table
      * @throws IllegalStateException if {@link #name} is not defined
@@ -1079,13 +1079,13 @@
      */
     public void onDeploy(ServletContext servletContext) {
         String[] files = new String[] {
-                "/net/sf/click/control/column-sortable-dark.gif",
-                "/net/sf/click/control/column-sortable-light.gif",
-                "/net/sf/click/control/column-ascending-dark.gif",
-                "/net/sf/click/control/column-ascending-light.gif",
-                "/net/sf/click/control/column-descending-dark.gif",
-                "/net/sf/click/control/column-descending-light.gif",
-                "/net/sf/click/control/table.css"
+                "/org/apache/click/control/column-sortable-dark.gif",
+                "/org/apache/click/control/column-sortable-light.gif",
+                "/org/apache/click/control/column-ascending-dark.gif",
+                "/org/apache/click/control/column-ascending-light.gif",
+                "/org/apache/click/control/column-descending-dark.gif",
+                "/org/apache/click/control/column-descending-light.gif",
+                "/org/apache/click/control/table.css"
             };
 
         for (int i = 0; i < files.length; i++) {
@@ -1098,7 +1098,7 @@
     /**
      * Initialize the controls contained in the Table.
      *
-     * @see net.sf.click.Control#onInit()
+     * @see org.apache.click.Control#onInit()
      */
     public void onInit() {
         super.onInit();
@@ -1111,7 +1111,7 @@
     /**
      * Perform any pre rendering logic.
      *
-     * @see net.sf.click.Control#onRender()
+     * @see org.apache.click.Control#onRender()
      */
     public void onRender() {
         for (int i = 0, size = getControls().size(); i < size; i++) {
@@ -1173,7 +1173,7 @@
      * <tt>clearRowListOnDestroy</tt> is true, set the sorted flag to false and
      * will invoke the onDestroy() method of any child controls.
      *
-     * @see net.sf.click.Control#onDestroy()
+     * @see org.apache.click.Control#onDestroy()
      */
     public void onDestroy() {
         sorted = false;

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Table.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/control/Table.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -193,7 +193,7 @@
  *
  * Table supports rendering different paginators through the method
- * {@link #setPaginator(net.sf.click.control.Renderable)}. The default Table
+ * {@link #setPaginator(org.apache.click.control.Renderable)}. The default Table
  * Paginator is {@link TablePaginator}.
  *

Copied: incubator/click/trunk/click/framework/src/org/apache/click/control/TablePaginator.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/control/TablePaginator.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/control/TablePaginator.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/control/TablePaginator.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/control/TablePaginator.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/service/ConfigService.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/service/ConfigService.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.service;
+package org.apache.click.service;
 
 import java.lang.reflect.Field;
 import java.util.Locale;
@@ -24,14 +24,14 @@
 
 import javax.servlet.ServletContext;
 
-import net.sf.click.util.Format;
+import org.apache.click.util.Format;
 
 /**
  * Provides a Click application configuration service interface.
  * <p/>
  * A single application ConfigService instance is created by the ClickServlet at
  * startup. Once the ConfigService has been initialized it is stored in the
  * ServletContext using the key "<tt>net.sf.click.service.ConfigService</tt>".
  *
  * <h3>Configuration</h3>
  * The default ConfigService is {@link XmlConfigService}.
@@ -44,7 +44,7 @@
  * <p/>
  * For Click to recognize your custom service class you must set the
  * context initialization parameter,
- * {@link net.sf.click.ClickServlet#CONFIG_SERVICE_CLASS config-service-class}
+ * {@link org.apache.click.ClickServlet#CONFIG_SERVICE_CLASS config-service-class}
  * in your <tt>web.xml</tt> file.
  * <p/>
  * Below is an example of a custom service class
@@ -120,7 +120,7 @@
      * application ConfigService instance in the ServletContext using this
      * context attribute name.
      */
-    public static final String CONTEXT_NAME = "net.sf.click.service.ConfigService";
+    public static final String CONTEXT_NAME = "org.apache.click.service.ConfigService";
 
     /**
      * Initialize the ConfigurationService with the given application servlet context.

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/service/ConfigService.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -24,14 +24,14 @@
  * A single application ConfigService instance is created by the ClickServlet at
  * startup. Once the ConfigService has been initialized it is stored in the
- * ServletContext using the key "<tt>net.sf.click.service.ConfigService</tt>".
+ * ServletContext using the key "<tt>org.apache.click.service.ConfigService</tt>".
  *
  * <h3>Configuration</h3>

Copied: incubator/click/trunk/click/framework/src/org/apache/click/service/ConsoleLogService.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/service/ConsoleLogService.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/service/ConsoleLogService.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/service/ConsoleLogService.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/service/ConsoleLogService.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================